pub fn list_named_keys() -> NamedKeysExpand description
Returns the named keys of the current context.
The current context is either the caller’s account or a stored contract depending on whether the currently-executing module is a direct call or a sub-call respectively.