Function casper_contract::contract_api::runtime::remove_key[][src]

pub fn remove_key(name: &str)
Removes the Key stored under name in the current context’s named keys.

The current context is either the caller’s account or a stored contract depending on whether the currently-executing module is a direct call or a sub-call respectively.