Module casper_contract::contract_api::runtime [−][src]
Functions for interacting with the current runtime.
Functions
Returns a 32-byte BLAKE2b digest
Calls the given stored contract, passing the given arguments to it.
Invokes the specified entry_point_name of stored logic at a specific contract_package_hash
address, for the most current version of a contract package by default or a specific
contract_version if one is provided, and passing the provided runtime_args to it
Returns the current BlockTime.
Returns the call stack.
Returns the caller of the current context, i.e. the AccountHash of the account which made
the deploy request.
Returns the requested named Key from the current context.
Returns given named argument passed to the host for the current module invocation.
Returns the current Phase.
Returns true if name exists in the current context’s named keys.
Validates uref against named keys.
Returns the named keys of the current context.
Stores the given Key under name in the current context’s named keys.
Removes the Key stored under name in the current context’s named keys.
Returns the given CLValue to the host, terminating the currently running module.
Stops execution of a contract and reverts execution effects with a given ApiError.