pub fn call_package_version<T: CLTyped + FromBytes>(
contract_package_hash: ContractPackageHash,
major_version: Option<u32>,
contract_version: Option<EntityVersion>,
entry_point_name: &str,
runtime_args: RuntimeArgs,
) -> TExpand description
Invokes the specified entry_point_name of stored logic at a specific contract_package_hash
address, for a specific pair of major_version and contract_version
and passing the provided runtime_args to it
If the stored contract calls ret, then that value is returned from
call_package_version. If the stored contract calls revert, then execution stops and
call_package_version doesn’t return. Otherwise call_package_version returns ().