pub fn new_contract(
entry_points: EntryPoints,
named_keys: Option<NamedKeys>,
hash_name: Option<String>,
uref_name: Option<String>,
message_topics: Option<BTreeMap<String, MessageTopicOperation>>,
) -> (ContractHash, EntityVersion)Expand description
Create a new contract stored under a Key::Hash at version 1. You may upgrade this contract in
the future; if you want a contract that is locked (i.e. cannot be upgraded) call
new_locked_contract instead.
if named_keys is provided, puts all of the included named keys into the newly created
contract version’s named keys.
if hash_name is provided, puts Key::Hash(contract_package_hash) into the
installing account’s named keys under hash_name.
if uref_name is provided, puts Key::URef(access_uref) into the installing account’s named
keys under uref_name