Module casper_contract::contract_api::system [−][src]
Functions for interacting with the system contracts.
Functions
Returns a read-only pointer to the Auction contract.
Returns the balance in motes of a purse.
Returns a read-only pointer to the Handle Payment contract.
Returns a read-only pointer to the Mint contract.
Returns a read-only pointer to the Standard Payment contract.
Transfers amount of motes from the default purse of the account to target
account. If target does not exist it will be created.